/* MediaInfoDLL - All info about media files, for DLL
// Copyright (C) 2002-2005 Jerome Martinez, Zen@MediaArea.net
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//
// Public DLL interface implementation
// Wrapper for MediaInfo Library
// Please see MediaInfo.h for help
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//
// 2005-06-22, Zen@MediaArea.net
// StreamNumber is signed (no change in the interface)
//
// 2005-05-18, Zen@MediaArea.net
// Added Optons in Inform function
//
// 2004-12-15, Zen@MediaArea.net
// Adaptation to new interface
// MediaInfoList Interface
//
// 2003-05-04, Zen@MediaArea.net
// Init
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

#ifndef MediaInfoDLLH
#define MediaInfoDLLH

#ifdef MEDIAINFO_DLL_EXPORT
#define MEDIAINFO_DLL extern _declspec(dllexport)
#else
#define MEDIAINFO_DLL extern _declspec(dllimport)
#endif

/** @brief Kinds of Stream */
typedef enum _stream_t
{
    Stream_General,
    Stream_Video,
    Stream_Audio,
    Stream_Text,
    Stream_Chapters,
    Stream_Image,
    Stream_Max
} stream_t_C;

/** @brief Kinds of Info */
typedef enum _info_t
{
    Info_Name,
    Info_Text,
    Info_Measure,
    Info_Options,
    Info_Name_Text,
    Info_Measure_Text,
    Info_Info,
    Info_HowTo,
    Info_Max
} info_t_C;

/** @brief Option if InfoKind = Info_Options */
typedef enum infooptions_t
{
    InfoOption_ShowInInform,
    InfoOption_Support,
    InfoOption_ShowInSupported,
    InfoOption_TypeOfValue,
    InfoOption_Max
} infooptions_t_C;

/** @brief Option for Inform */
typedef enum informoptions_t
{
    InformOption_Nothing,
    InformOption_Custom,
    InformOption_HTML,
    InformOption_Max
} informoptions_t_C;

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

/***************************************************************************/
/*! \file MediaInfoDll.h
\brief DLL wrapper for MediaInfo.h.

DLL wrapper for MediaInfo.h \n
	Written in C \n
    "Handle" replaces class definition
*/
/***************************************************************************/

/** @brief Wrapper for MediaInfoLib::MediaInfo::Open (with a filename) */
MEDIAINFO_DLL void*		    __stdcall MediaInfoA_Open (const char* File); /*return Handle*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Open (with a buffer) */
MEDIAINFO_DLL void*          __stdcall MediaInfoA_Open_Buffer (const unsigned char* Begin, unsigned int Begin_Size, const unsigned char* End, unsigned int End_Size); /*return Handle*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Save */
MEDIAINFO_DLL int            __stdcall MediaInfoA_Save (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Close */
MEDIAINFO_DLL void           __stdcall MediaInfoA_Close (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Inform */
MEDIAINFO_DLL const char*    __stdcall MediaInfoA_Inform (void* Handle, informoptions_t Options); /*Default : Options=0*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Get */
MEDIAINFO_DLL const char*    __stdcall MediaInfoA_GetI (void* Handle, stream_t_C StreamKind, int StreamNumber, unsigned int Parameter, info_t_C InfoKind); /*Default : InfoKind=Info_Text*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Get */
MEDIAINFO_DLL const char*    __stdcall MediaInfoA_Get (void* Handle, stream_t_C StreamKind, int StreamNumber, const char* Parameter, info_t_C InfoKind, info_t_C SearchKind); /*Default : InfoKind=Info_Text, SearchKind=Info_Name*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Set */
MEDIAINFO_DLL int            __stdcall MediaInfoA_SetI (void* Handle, const char* ToSet, stream_t_C StreamKind, int StreamNumber, unsigned int Parameter, const char* OldParameter);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Set */
MEDIAINFO_DLL int            __stdcall MediaInfoA_Set (void* Handle, const char* ToSet, stream_t_C StreamKind, int StreamNumber, const char* Parameter, const char* OldParameter);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Option */
MEDIAINFO_DLL const char*    __stdcall MediaInfoA_Option (void* Handle, const char* Option, const char* Value);
/** @brief Wrapper for MediaInfoLib::MediaInfo::State_Get */
MEDIAINFO_DLL int	         __stdcall MediaInfoA_State_Get (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Count_Get */
MEDIAINFO_DLL int            __stdcall MediaInfoA_Count_Get (void* Handle, stream_t_C StreamKind, int StreamNumber); /*Default : StreamNumber=-1*/

/** @brief Wrapper for MediaInfoLib::MediaInfo::Open (with a filename)*/
MEDIAINFO_DLL void*          __stdcall MediaInfo_Open (const wchar_t* File); /*return Handle*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Open (with a buffer) */
MEDIAINFO_DLL void*          __stdcall MediaInfo_Open_Buffer (const unsigned char* Begin, unsigned int Begin_Size, const unsigned char* End, unsigned int End_Size); /*return Handle*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Save */
MEDIAINFO_DLL int            __stdcall MediaInfo_Save (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Close */
MEDIAINFO_DLL void           __stdcall MediaInfo_Close (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Inform */
MEDIAINFO_DLL const wchar_t* __stdcall MediaInfo_Inform (void* Handle, informoptions_t Options); /*Default : Options=0*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Get */
MEDIAINFO_DLL const wchar_t* __stdcall MediaInfo_GetI (void* Handle, stream_t_C StreamKind, int StreamNumber, unsigned int Parameter, info_t_C InfoKind); /*Default : InfoKind=Info_Text*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Get */
MEDIAINFO_DLL const wchar_t* __stdcall MediaInfo_Get (void* Handle, stream_t_C StreamKind, int StreamNumber, const wchar_t* Parameter, info_t_C InfoKind, info_t_C SearchKind); /*Default : InfoKind=Info_Text, SearchKind=Info_Name*/
/** @brief Wrapper for MediaInfoLib::MediaInfo::Set */
MEDIAINFO_DLL int            __stdcall MediaInfo_SetI (void* Handle, const wchar_t* ToSet, stream_t_C StreamKind, int StreamNumber, unsigned int Parameter, const wchar_t* OldParameter);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Set */
MEDIAINFO_DLL int            __stdcall MediaInfo_Set (void* Handle, const wchar_t* ToSet, stream_t_C StreamKind, int StreamNumber, const wchar_t* Parameter, const wchar_t* OldParameter);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Options */
MEDIAINFO_DLL const wchar_t* __stdcall MediaInfo_Option (void* Handle, const wchar_t* Option, const wchar_t* Value);
/** @brief Wrapper for MediaInfoLib::MediaInfo::State_Get */
MEDIAINFO_DLL int	         __stdcall MediaInfo_State_Get (void* Handle);
/** @brief Wrapper for MediaInfoLib::MediaInfo::Count_Get */
MEDIAINFO_DLL int            __stdcall MediaInfo_Count_Get (void* Handle, stream_t_C StreamKind, int StreamNumber); /*Default : StreamNumber=-1*/
/** @brief Warning : Deprecated, use MediaInfo_Option("Info_Version", "") instead */
MEDIAINFO_DLL const char*    __stdcall MediaInfo_Info_Version ();

#ifdef __cplusplus
}
#endif /*__cplusplus*/

#endif
